#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-bash
version:              1.0.37
visibility:           public
id:                   dhall-bash-1.0.37-L6HE5C3MKiPBlNoATJGeP4
key:                  dhall-bash-1.0.37-L6HE5C3MKiPBlNoATJGeP4
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  8afebd95cf8f611c933d0b61cd9cc78a
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-8.10.5/site-local/dhall-bash-1.0.37
library-dirs:         /usr/lib/ghc-8.10.5/site-local/dhall-bash-1.0.37
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.37-L6HE5C3MKiPBlNoATJGeP4
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    dhall-1.39.0-7VzSqvXon9HAtuy5pJaNgD
    neat-interpolation-0.5.1.2-JTlL2903Vj3LniIl9nKYXo
    shell-escape-0.2.0-1nFNUOkhNba9Z5brVZ0J1L text-1.2.4.1

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

